@@ -90,6 +90,8 @@ class QAStage(Stage):
         ##
         best_res_score = worker_response[0][1]
         best_res_responds = self.corpus[best_res_content] if best_res_content in self.corpus else None
+        if isinstance(best_res_responds,list):
+            best_res_responds = random.choice(best_res_responds)
 
         ##
         __RUNNING_CORPUS__ = get_value_from_dict_by_multi_name(d=self.saved_name, names=self.__RUNNING_CORPUS__,
